@@ -29,100 +29,100 @@
  * and longs must be addressable on word boundaries.
  */
 
-
 #if !defined(INCLUDE_ZMATH_H)
-#define INCLUDE_ZMATH_H
+#  define INCLUDE_ZMATH_H
 
+#  if defined(CALC_SRC) /* if we are building from the calc source tree */
+#    include "version.h"
+#    include "bool.h"
+#    include "decl.h"
+#    include "alloc.h"
+#    include "endian_calc.h"
+#    include "longbits.h"
+#    include "byteswap.h"
+#    include "have_stdlib.h"
+#    include "charbit.h"
+#  else
+#    include <calc/version.h>
+#    include <calc/bool.h>
+#    include <calc/decl.h>
+#    include <calc/alloc.h>
+#    include <calc/endian_calc.h>
+#    include <calc/longbits.h>
+#    include <calc/byteswap.h>
+#    include <calc/have_stdlib.h>
+#    include <calc/charbit.h>
+#  endif
+#  ifdef HAVE_STDLIB_H
+#    include <stdlib.h>
+#  endif
 
-#if defined(CALC_SRC)   /* if we are building from the calc source tree */
-# include "version.h"
-# include "bool.h"
-# include "decl.h"
-# include "alloc.h"
-# include "endian_calc.h"
-# include "longbits.h"
-# include "byteswap.h"
-# include "have_stdlib.h"
-# include "charbit.h"
-#else
-# include <calc/version.h>
-# include <calc/bool.h>
-# include <calc/decl.h>
-# include <calc/alloc.h>
-# include <calc/endian_calc.h>
-# include <calc/longbits.h>
-# include <calc/byteswap.h>
-# include <calc/have_stdlib.h>
-# include <calc/charbit.h>
-#endif
-#ifdef HAVE_STDLIB_H
-# include <stdlib.h>
-#endif
-
-
-#ifndef ALLOCTEST
-# define freeh(p) { if (!is_const(p)) { free((void *)(p)); } }
-#endif
-
+#  ifndef ALLOCTEST
+#    define freeh(p)               \
+        {                          \
+            if (!is_const(p)) {    \
+                free((void *)(p)); \
+            }                      \
+        }
+#  endif
 
 /*
  * NOTE: FULL must be twice the storage size of a HALF
  *       HALF must be BASEB bits long
  */
 
-#if defined(HAVE_B64)
+#  if defined(HAVE_B64)
 
 /* BTW: BASEB is effectively HALF_BITS */
 
-#define BASEB   32                      /* use base 2^32 */
-typedef USB32 HALF;                     /* unit of number storage */
-typedef SB32 SHALF;                     /* signed HALF */
-typedef USB64 FULL;                     /* double unit of number storage */
-typedef SB64 SFULL;                     /* signed FULL */
+#    define BASEB 32 /* use base 2^32 */
+typedef USB32 HALF;  /* unit of number storage */
+typedef SB32 SHALF;  /* signed HALF */
+typedef USB64 FULL;  /* double unit of number storage */
+typedef SB64 SFULL;  /* signed FULL */
 
-#define SWAP_HALF_IN_B64(dest, src)     SWAP_B32_IN_B64(dest, src)
-#define SWAP_HALF_IN_B32(dest, src)     (*((HALF *)(dest)) = *((HALF *)(src)))
-#define SWAP_HALF_IN_FULL(dest, src)    SWAP_B32_IN_B64(dest, src)
-#define SWAP_HALF_IN_HASH(dest, src)    SWAP_B16_IN_HASH(dest, src)
-#define SWAP_HALF_IN_FLAG(dest, src)    SWAP_B16_IN_FLAG(dest, src)
-#define SWAP_HALF_IN_bool(dest, src)    SWAP_B16_IN_bool(dest, src)
-#define SWAP_HALF_IN_LEN(dest, src)     SWAP_B16_IN_LEN(dest, src)
-#define SWAP_B32_IN_FULL(dest, src)     SWAP_B32_IN_B64(dest, src)
-#define SWAP_B16_IN_FULL(dest, src)     SWAP_B16_IN_B64(dest, src)
-#define SWAP_B16_IN_HALF(dest, src)     SWAP_B16_IN_B32(dest, src)
-#define SWAP_B8_IN_FULL(dest, src)      SWAP_B8_IN_B64(dest, src)
-#define SWAP_B8_IN_HALF(dest, src)      SWAP_B8_IN_B32(dest, src)
+#    define SWAP_HALF_IN_B64(dest, src) SWAP_B32_IN_B64(dest, src)
+#    define SWAP_HALF_IN_B32(dest, src) (*((HALF *)(dest)) = *((HALF *)(src)))
+#    define SWAP_HALF_IN_FULL(dest, src) SWAP_B32_IN_B64(dest, src)
+#    define SWAP_HALF_IN_HASH(dest, src) SWAP_B16_IN_HASH(dest, src)
+#    define SWAP_HALF_IN_FLAG(dest, src) SWAP_B16_IN_FLAG(dest, src)
+#    define SWAP_HALF_IN_bool(dest, src) SWAP_B16_IN_bool(dest, src)
+#    define SWAP_HALF_IN_LEN(dest, src) SWAP_B16_IN_LEN(dest, src)
+#    define SWAP_B32_IN_FULL(dest, src) SWAP_B32_IN_B64(dest, src)
+#    define SWAP_B16_IN_FULL(dest, src) SWAP_B16_IN_B64(dest, src)
+#    define SWAP_B16_IN_HALF(dest, src) SWAP_B16_IN_B32(dest, src)
+#    define SWAP_B8_IN_FULL(dest, src) SWAP_B8_IN_B64(dest, src)
+#    define SWAP_B8_IN_HALF(dest, src) SWAP_B8_IN_B32(dest, src)
 
-#else
+#  else
 
-#define BASEB   16                      /* use base 2^16 */
-typedef USB16 HALF;                     /* unit of number storage */
-typedef SB16 SHALF;                     /* signed HALF */
-typedef USB32 FULL;                     /* double unit of number storage */
-typedef SB32 SFULL;                     /* signed FULL */
+#    define BASEB 16 /* use base 2^16 */
+typedef USB16 HALF; /* unit of number storage */
+typedef SB16 SHALF; /* signed HALF */
+typedef USB32 FULL; /* double unit of number storage */
+typedef SB32 SFULL; /* signed FULL */
 
-#define SWAP_HALF_IN_B64(dest, src)     SWAP_B16_IN_B64(dest, src)
-#define SWAP_HALF_IN_B32(dest, src)     SWAP_B16_IN_B32(dest, src)
-#define SWAP_HALF_IN_FULL(dest, src)    SWAP_B16_IN_B32(dest, src)
-#define SWAP_HALF_IN_HASH(dest, src)    SWAP_B16_IN_HASH(dest, src)
-#define SWAP_HALF_IN_FLAG(dest, src)    SWAP_B16_IN_FLAG(dest, src)
-#define SWAP_HALF_IN_bool(dest, src)    SWAP_B16_IN_bool(dest, src)
-#define SWAP_HALF_IN_LEN(dest, src)     SWAP_B16_IN_LEN(dest, src)
-#define SWAP_B32_IN_FULL(dest, src)     (*((FULL *)(dest)) = *((FULL *)(src)))
-#define SWAP_B16_IN_FULL(dest, src)     SWAP_B16_IN_B32(dest, src)
-#define SWAP_B16_IN_HALF(dest, src)     (*((HALF *)(dest)) = *((HALF *)(src)))
-#define SWAP_B8_IN_FULL(dest, src)      SWAP_B8_IN_B32(dest, src)
-#define SWAP_B8_IN_HALF(dest, src)      SWAP_B8_IN_B16(dest, src)
+#    define SWAP_HALF_IN_B64(dest, src) SWAP_B16_IN_B64(dest, src)
+#    define SWAP_HALF_IN_B32(dest, src) SWAP_B16_IN_B32(dest, src)
+#    define SWAP_HALF_IN_FULL(dest, src) SWAP_B16_IN_B32(dest, src)
+#    define SWAP_HALF_IN_HASH(dest, src) SWAP_B16_IN_HASH(dest, src)
+#    define SWAP_HALF_IN_FLAG(dest, src) SWAP_B16_IN_FLAG(dest, src)
+#    define SWAP_HALF_IN_bool(dest, src) SWAP_B16_IN_bool(dest, src)
+#    define SWAP_HALF_IN_LEN(dest, src) SWAP_B16_IN_LEN(dest, src)
+#    define SWAP_B32_IN_FULL(dest, src) (*((FULL *)(dest)) = *((FULL *)(src)))
+#    define SWAP_B16_IN_FULL(dest, src) SWAP_B16_IN_B32(dest, src)
+#    define SWAP_B16_IN_HALF(dest, src) (*((HALF *)(dest)) = *((HALF *)(src)))
+#    define SWAP_B8_IN_FULL(dest, src) SWAP_B8_IN_B32(dest, src)
+#    define SWAP_B8_IN_HALF(dest, src) SWAP_B8_IN_B16(dest, src)
 
-#endif
-
-#define BASE    ((FULL)1<<BASEB)                /* base for calculations */
-#define BASE1   (BASE - (FULL)1)                /* one less than base */
-#define BASEDIG ((BASEB/16)*5)                  /* number of digits in base */
-#define FULL_BITS (2*BASEB)                     /* bits in a FULL */
-#define HALF_LEN (sizeof(HALF))                 /* length of HALF in bytes */
-#define FULL_LEN (sizeof(FULL))                 /* length of FULL in bytes */
+#  endif
 
+#  define BASE ((FULL)1 << BASEB)    /* base for calculations */
+#  define BASE1 (BASE - (FULL)1)     /* one less than base */
+#  define BASEDIG ((BASEB / 16) * 5) /* number of digits in base */
+#  define FULL_BITS (2 * BASEB)      /* bits in a FULL */
+#  define HALF_LEN (sizeof(HALF))    /* length of HALF in bytes */
+#  define FULL_LEN (sizeof(FULL))    /* length of FULL in bytes */
 
 /*
  * ROUNDUP(value, mult) - round up value to the next multiple of mult
@@ -134,59 +134,57 @@ typedef SB32 SFULL;                     /* signed FULL */
  * NOTE: If value is a multiple of mult, then ROUNDUP(value, mult)
  *       will just return value.
  */
-#define ROUNDUP(value, mult) ( ( ((value)+(mult)-1) / (mult) ) * (mult) )
+#  define ROUNDUP(value, mult) ((((value) + (mult) - 1) / (mult)) * (mult))
 
-#define TOPHALF ((FULL)1 << (BASEB-1))          /* highest bit in a HALF */
-#define MAXHALF (TOPHALF - (FULL)1)             /* largest SHALF value */
+#  define TOPHALF ((FULL)1 << (BASEB - 1)) /* highest bit in a HALF */
+#  define MAXHALF (TOPHALF - (FULL)1)      /* largest SHALF value */
 
-#define TOPFULL ((FULL)1 << (FULL_BITS-1))      /* highest bit in FULL */
-#define MAXFULL (TOPFULL - (FULL)1)             /* largest SFULL value */
-#define MINSFULL ((SFULL)(TOPFULL))             /* most negative SFULL value */
-#define MAXUFULL (MAXFULL | TOPFULL)            /* largest FULL value */
-
-#define TOPLONG ((unsigned long)1 << (LONG_BITS-1))     /* top long bit */
-#define MAXLONG ((long) (TOPLONG - (unsigned long)1))   /* largest long val */
-#define MAXULONG (MAXLONG | TOPLONG)            /* largest unsigned long val */
+#  define TOPFULL ((FULL)1 << (FULL_BITS - 1)) /* highest bit in FULL */
+#  define MAXFULL (TOPFULL - (FULL)1)          /* largest SFULL value */
+#  define MINSFULL ((SFULL)(TOPFULL))          /* most negative SFULL value */
+#  define MAXUFULL (MAXFULL | TOPFULL)         /* largest FULL value */
 
+#  define TOPLONG ((unsigned long)1 << (LONG_BITS - 1)) /* top long bit */
+#  define MAXLONG ((long)(TOPLONG - (unsigned long)1))  /* largest long val */
+#  define MAXULONG (MAXLONG | TOPLONG)                  /* largest unsigned long val */
 
 /*
  * other miscellaneous typedefs
  */
-typedef USB32 QCKHASH;                  /* 32 bit hash value */
-#if defined(HAVE_B64) && LONG_BITS == 32
-typedef HALF PRINT;                     /* cast for zio printing functions */
-#define SWAP_B16_IN_PRINT(dest, src)    SWAP_B16_IN_HALF(dest, src)
-#define SWAP_B8_IN_PRINT(dest, src)     SWAP_B8_IN_HALF(dest, src)
-#else
-typedef FULL PRINT;                     /* cast for zio printing functions */
-#define SWAP_B16_IN_PRINT(dest, src)    SWAP_B16_IN_FULL(dest, src)
-#define SWAP_B8_IN_PRINT(dest, src)     SWAP_B8_IN_FULL(dest, src)
-#endif
-typedef SB32 FLAG;                      /* small value (e.g. comparison) */
+typedef USB32 QCKHASH; /* 32 bit hash value */
+#  if defined(HAVE_B64) && LONG_BITS == 32
+typedef HALF PRINT; /* cast for zio printing functions */
+#    define SWAP_B16_IN_PRINT(dest, src) SWAP_B16_IN_HALF(dest, src)
+#    define SWAP_B8_IN_PRINT(dest, src) SWAP_B8_IN_HALF(dest, src)
+#  else
+typedef FULL PRINT; /* cast for zio printing functions */
+#    define SWAP_B16_IN_PRINT(dest, src) SWAP_B16_IN_FULL(dest, src)
+#    define SWAP_B8_IN_PRINT(dest, src) SWAP_B8_IN_FULL(dest, src)
+#  endif
+typedef SB32 FLAG; /* small value (e.g. comparison) */
 
 /*
  * length of internal integer values in units of HALF
  */
-#if MAJOR_VER < 3
-typedef SB32 LEN;                       /* calc v2 compatible unit of length storage */
-#else /* MAJOR_VER < 3 */
-typedef uintptr_t LEN;                  /* unit of length storage */
-#endif /* MAJOR_VER < 3 */
+#  if MAJOR_VER < 3
+typedef SB32 LEN; /* calc v2 compatible unit of length storage */
+#  else           /* MAJOR_VER < 3 */
+typedef uintptr_t LEN; /* unit of length storage */
+#  endif          /* MAJOR_VER < 3 */
 
-#define SWAP_B32_IN_bool(dest, src)     (*((bool *)(dest)) = *((bool *)(src)))
-#define SWAP_B16_IN_bool(dest, src)     SWAP_B16_IN_B32(dest, src)
-#define SWAP_B8_IN_bool(dest, src)      SWAP_B8_IN_B32(dest, src)
+#  define SWAP_B32_IN_bool(dest, src) (*((bool *)(dest)) = *((bool *)(src)))
+#  define SWAP_B16_IN_bool(dest, src) SWAP_B16_IN_B32(dest, src)
+#  define SWAP_B8_IN_bool(dest, src) SWAP_B8_IN_B32(dest, src)
 
-#define SWAP_B32_IN_LEN(dest, src)      (*((LEN *)(dest)) = *((LEN *)(src)))
-#define SWAP_B16_IN_LEN(dest, src)      SWAP_B16_IN_B32(dest, src)
-#define SWAP_B8_IN_LEN(dest, src)       SWAP_B8_IN_B32(dest, src)
-
-#if LONG_BITS == 64
-#define SWAP_HALF_IN_LONG(dest, src)    SWAP_HALF_IN_B64(dest, src)
-#else /* LONG_BITS == 64 */
-#define SWAP_HALF_IN_LONG(dest, src)    SWAP_HALF_IN_B32(dest, src)
-#endif /* LONG_BITS == 64 */
+#  define SWAP_B32_IN_LEN(dest, src) (*((LEN *)(dest)) = *((LEN *)(src)))
+#  define SWAP_B16_IN_LEN(dest, src) SWAP_B16_IN_B32(dest, src)
+#  define SWAP_B8_IN_LEN(dest, src) SWAP_B8_IN_B32(dest, src)
 
+#  if LONG_BITS == 64
+#    define SWAP_HALF_IN_LONG(dest, src) SWAP_HALF_IN_B64(dest, src)
+#  else /* LONG_BITS == 64 */
+#    define SWAP_HALF_IN_LONG(dest, src) SWAP_HALF_IN_B32(dest, src)
+#  endif /* LONG_BITS == 64 */
 
 /*
  * Quickhash basis
@@ -222,15 +220,13 @@ typedef uintptr_t LEN;                  /* unit of length storage */
  * to be a cryptographic hash function, just a fast and reasonably
  * good hash function.
  */
-#define QUICKHASH_BASIS ((QCKHASH)(0x811c9dc5))
-
+#  define QUICKHASH_BASIS ((QCKHASH)(0x811c9dc5))
 
 /*
  * The largest power of 10 we will compute for our decimal conversion
  * internal constants is: 10^(2^TEN_MAX).
  */
-#define TEN_MAX 31      /* 10^2^31 requires about 1.66 * 2^29 bytes */
-
+#  define TEN_MAX 31 /* 10^2^31 requires about 1.66 * 2^29 bytes */
 
 /*
  * MAXDATA - largest data object in bytes we will use
@@ -242,14 +238,13 @@ typedef uintptr_t LEN;                  /* unit of length storage */
  * NOTE: MAXDATA must be 1 less than a power of 2.
  * NOTE: MAXDATA_LOG2 is the log base 2 of MAXDATA+1.
  */
-#if MAJOR_VER < 3
-#define MAXDATA_LOG2 (28)                       /* as defined by calc v2 */
-#define MAXDATA ((1<<MAXDATA_LOG2) - 1)         /* calc v2 compatible supported address space */
-#else /* MAJOR_VER < 3 */
-#define MAXDATA_LOG2 (UINTPTR_WIDTH - 3)        /* 1/8 of address space */
-#define MAXDATA (((LEN) 1<<MAXDATA_LOG2) - 1)
-#endif /* MAJOR_VER < 3 */
-
+#  if MAJOR_VER < 3
+#    define MAXDATA_LOG2 (28)                 /* as defined by calc v2 */
+#    define MAXDATA ((1 << MAXDATA_LOG2) - 1) /* calc v2 compatible supported address space */
+#  else                                       /* MAJOR_VER < 3 */
+#    define MAXDATA_LOG2 (UINTPTR_WIDTH - 3)  /* 1/8 of address space */
+#    define MAXDATA (((LEN)1 << MAXDATA_LOG2) - 1)
+#  endif /* MAJOR_VER < 3 */
 
 /*
  * MAXLEN - maximum length of internal integer values in units of HALF
@@ -260,74 +255,66 @@ typedef uintptr_t LEN;                  /* unit of length storage */
  * NOTE: MAXLEN must be 1 less than a power of 2.
  * NOTE: MAXLEN_LOG2 is the log base 2 of MAXLEN+1.
  */
-#define MAXLEN ((LEN) ((MAXDATA / HALF_LEN) - 1))       /* longest value allowed */
-#define MAXLEN_LOG2 (MAXDATA_LOG2 - BASEB)
+#  define MAXLEN ((LEN)((MAXDATA / HALF_LEN) - 1)) /* longest value allowed */
+#  define MAXLEN_LOG2 (MAXDATA_LOG2 - BASEB)
 
-
-#define MAXREDC 256                     /* number of entries in REDC cache */
-#define SQ_ALG2 28                      /* size for alternative squaring */
-#define MUL_ALG2 28                     /* size for alternative multiply */
-#define POW_ALG2 20                     /* size for using REDC for powers */
+#  define MAXREDC 256 /* number of entries in REDC cache */
+#  define SQ_ALG2 28  /* size for alternative squaring */
+#  define MUL_ALG2 28 /* size for alternative multiply */
+#  define POW_ALG2 20 /* size for using REDC for powers */
 /* old REDC_ALG2 was 5/4 of POW_ALG2, so we will keep the same ratio */
-#define REDC_ALG2 25                    /* size for using alternative REDC */
-
+#  define REDC_ALG2 25 /* size for using alternative REDC */
 
 typedef union {
-        FULL    ivalue;
-        struct {
-                HALF Svalue1;
-                HALF Svalue2;
-        } sis;
+    FULL ivalue;
+    struct {
+        HALF Svalue1;
+        HALF Svalue2;
+    } sis;
 } SIUNION;
 
-
-#if !defined(LITTLE_ENDIAN)
-#define LITTLE_ENDIAN   1234    /* Least Significant Byte first */
-#endif
-#if !defined(BIG_ENDIAN)
-#define BIG_ENDIAN      4321    /* Most Significant Byte first */
-#endif
+#  if !defined(LITTLE_ENDIAN)
+#    define LITTLE_ENDIAN 1234 /* Least Significant Byte first */
+#  endif
+#  if !defined(BIG_ENDIAN)
+#    define BIG_ENDIAN 4321 /* Most Significant Byte first */
+#  endif
 /* PDP_ENDIAN - LSB in word, MSW in long is not supported */
 
-#if CALC_BYTE_ORDER == LITTLE_ENDIAN
-# define silow  sis.Svalue1     /* low order half of full value */
-# define sihigh sis.Svalue2     /* high order half of full value */
-#else
-# if CALC_BYTE_ORDER == BIG_ENDIAN
-#  define silow sis.Svalue2     /* low order half of full value */
-#  define sihigh sis.Svalue1    /* high order half of full value */
-# else
-   /\oo/\    CALC_BYTE_ORDER must be BIG_ENDIAN or LITTLE_ENDIAN    /\oo/\  !!!
-# endif
-#endif
-
-
+#  if CALC_BYTE_ORDER == LITTLE_ENDIAN
+#    define silow sis.Svalue1  /* low order half of full value */
+#    define sihigh sis.Svalue2 /* high order half of full value */
+#  else
+#    if CALC_BYTE_ORDER == BIG_ENDIAN
+#      define silow sis.Svalue2  /* low order half of full value */
+#      define sihigh sis.Svalue1 /* high order half of full value */
+#    else
+/\oo /\ CALC_BYTE_ORDER must be BIG_ENDIAN or LITTLE_ENDIAN /\oo /\ !!!
+#    endif
+#  endif
 
 /*
  * ZVALUE - multi-prevision integer
  */
-#if MAJOR_VER < 3
-typedef SB32 SIGN;                      /* calc v2 compatible sign type */
-#else /* MAJOR_VER < 3 */
-typedef bool SIGN;                      /* sign as a C boolean */
-#endif /* MAJOR_VER < 3 */
+#  if MAJOR_VER < 3
+typedef SB32 SIGN; /* calc v2 compatible sign type */
+#  else            /* MAJOR_VER < 3 */
+typedef bool SIGN; /* sign as a C boolean */
+#  endif           /* MAJOR_VER < 3 */
 typedef struct {
-        HALF    *v;             /* pointer to array of values */
-        LEN     len;            /* number of values in array */
-        SIGN    sign;           /* sign, nonzero is negative */
+    HALF *v;   /* pointer to array of values */
+    LEN len;   /* number of values in array */
+    SIGN sign; /* sign, nonzero is negative */
 } ZVALUE;
 
-
-
 /*
  * Function prototypes for integer math routines.
  */
-E_FUNC HALF * alloc(LEN len);
-E_FUNC int is_const(HALF* h);
-#ifdef  ALLOCTEST
+E_FUNC HALF *alloc(LEN len);
+E_FUNC int is_const(HALF *h);
+#  ifdef ALLOCTEST
 E_FUNC void freeh(HALF *);
-#endif
-
+#  endif
 
 /*
  * Input, output, and conversion routines.
@@ -346,7 +333,6 @@ E_FUNC void zprintb(ZVALUE z, long width);
 E_FUNC void zprinto(ZVALUE z, long width);
 E_FUNC void fitzprint(ZVALUE, long, long);
 
-
 /*
  * Basic numeric routines.
  */
@@ -380,7 +366,6 @@ E_FUNC FLAG zrel(ZVALUE z1, ZVALUE z2);
 E_FUNC FLAG zabsrel(ZVALUE z1, ZVALUE z2);
 E_FUNC bool zcmp(ZVALUE z1, ZVALUE z2);
 
-
 /*
  * More complicated numeric functions.
  */
@@ -412,7 +397,6 @@ E_FUNC bool zissquare(ZVALUE z);
 E_FUNC void zhnrmod(ZVALUE v, ZVALUE h, ZVALUE zn, ZVALUE zr, ZVALUE *res);
 E_FUNC bool zispowerof2(ZVALUE z, FULL *log2);
 
-
 /*
  * Prime related functions.
  */
@@ -423,16 +407,13 @@ E_FUNC FULL zpprime(ZVALUE z);
 E_FUNC void zpfact(ZVALUE z, ZVALUE *dest);
 E_FUNC bool zprimetest(ZVALUE z, long count, ZVALUE skip);
 E_FUNC bool zredcprimetest(ZVALUE z, long count, ZVALUE skip);
-E_FUNC bool znextcand(ZVALUE z1, long count, ZVALUE skip, ZVALUE res,
-                      ZVALUE mod, ZVALUE *cand);
-E_FUNC bool zprevcand(ZVALUE z1, long count, ZVALUE skip, ZVALUE res,
-                      ZVALUE mod, ZVALUE *cand);
+E_FUNC bool znextcand(ZVALUE z1, long count, ZVALUE skip, ZVALUE res, ZVALUE mod, ZVALUE *cand);
+E_FUNC bool zprevcand(ZVALUE z1, long count, ZVALUE skip, ZVALUE res, ZVALUE mod, ZVALUE *cand);
 E_FUNC FULL zlowfactor(ZVALUE z, long count);
 E_FUNC FLAG zfactor(ZVALUE z1, ZVALUE z2, ZVALUE *res);
 E_FUNC long zpix(ZVALUE z1);
 E_FUNC void zlcmfact(ZVALUE z, ZVALUE *dest);
 
-
 /*
  * miscellaneous functions. :-)
  */
@@ -441,7 +422,6 @@ E_FUNC void zminmod(ZVALUE z1, ZVALUE z2, ZVALUE *res);
 E_FUNC bool zcmpmod(ZVALUE z1, ZVALUE z2, ZVALUE z3);
 E_FUNC void zio_init(void);
 
-
 /*
  * These functions are for internal use only.
  */
@@ -450,7 +430,6 @@ E_FUNC void zshiftr(ZVALUE z, long n);
 E_FUNC void zshiftl(ZVALUE z, long n);
 E_FUNC HALF *zalloctemp(LEN len);
 
-
 /*
  * Modulo arithmetic definitions.
  * Structure holding state of REDC initialization.
@@ -459,10 +438,10 @@ E_FUNC HALF *zalloctemp(LEN len);
  * Len of zero means the structure is not initialized.
  */
 typedef struct {
-        LEN len;                /* number of words in binary modulus */
-        ZVALUE mod;             /* modulus REDC is computing with */
-        ZVALUE inv;             /* inverse of modulus in binary modulus */
-        ZVALUE one;             /* REDC format for the number 1 */
+    LEN len;    /* number of words in binary modulus */
+    ZVALUE mod; /* modulus REDC is computing with */
+    ZVALUE inv; /* inverse of modulus in binary modulus */
+    ZVALUE one; /* REDC format for the number 1 */
 } REDC;
 
 E_FUNC REDC *zredcalloc(ZVALUE z1);
@@ -473,55 +452,52 @@ E_FUNC void zredcmul(REDC *rp, ZVALUE z1, ZVALUE z2, ZVALUE *res);
 E_FUNC void zredcsquare(REDC *rp, ZVALUE z1, ZVALUE *res);
 E_FUNC void zredcpower(REDC *rp, ZVALUE z1, ZVALUE z2, ZVALUE *res);
 
-
 /*
  * macro expansions to speed this thing up
  */
-#define ziseven(z)      (!(*(z).v & 0x1))
-#define zisodd(z)       (*(z).v & 0x1)
-#define ziszero(z)      ((*(z).v == 0) && ((z).len == 1))
-#define zisneg(z)       ((z).sign)
-#define zispos(z)       (((z).sign == 0) && (*(z).v || ((z).len > 1)))
-#define zisunit(z)      ((*(z).v == 1) && ((z).len == 1))
-#define zisone(z)       ((*(z).v == 1) && ((z).len == 1) && !(z).sign)
-#define zisnegone(z)    ((*(z).v == 1) && ((z).len == 1) && (z).sign)
-#define zltnegone(z)    (zisneg(z) && (((z).len > 1) || *(z).v > 1))
-#define zistwo(z)       ((*(z).v == 2) && ((z).len == 1) && !(z).sign)
-#define zisabstwo(z)    ((*(z).v == 2) && ((z).len == 1))
-#define zisabsleone(z)  ((*(z).v <= 1) && ((z).len == 1))
-#define zislezero(z)    (zisneg(z) || ziszero(z))
-#define zisleone(z)     (zisneg(z) || zisabsleone(z))
-#define zistiny(z)      ((z).len == 1)
+#  define ziseven(z) (!(*(z).v & 0x1))
+#  define zisodd(z) (*(z).v & 0x1)
+#  define ziszero(z) ((*(z).v == 0) && ((z).len == 1))
+#  define zisneg(z) ((z).sign)
+#  define zispos(z) (((z).sign == 0) && (*(z).v || ((z).len > 1)))
+#  define zisunit(z) ((*(z).v == 1) && ((z).len == 1))
+#  define zisone(z) ((*(z).v == 1) && ((z).len == 1) && !(z).sign)
+#  define zisnegone(z) ((*(z).v == 1) && ((z).len == 1) && (z).sign)
+#  define zltnegone(z) (zisneg(z) && (((z).len > 1) || *(z).v > 1))
+#  define zistwo(z) ((*(z).v == 2) && ((z).len == 1) && !(z).sign)
+#  define zisabstwo(z) ((*(z).v == 2) && ((z).len == 1))
+#  define zisabsleone(z) ((*(z).v <= 1) && ((z).len == 1))
+#  define zislezero(z) (zisneg(z) || ziszero(z))
+#  define zisleone(z) (zisneg(z) || zisabsleone(z))
+#  define zistiny(z) ((z).len == 1)
 
 /*
  * zgtmaxfull(z)        true if abs(z) > MAXFULL
  */
-#define zgtmaxfull(z)   (((z).len > 2) || (((z).len == 2) && \
-                         (((SHALF)(z).v[1]) < 0)))
+#  define zgtmaxfull(z) (((z).len > 2) || (((z).len == 2) && (((SHALF)(z).v[1]) < 0)))
 
 /*
  * zgtmaxufull(z)       true if abs(z) will not fit into a FULL (> MAXUFULL)
  */
-#define zgtmaxufull(z)  ((z).len > 2)
+#  define zgtmaxufull(z) ((z).len > 2)
 
 /*
  * zgtmaxulong(z)       true if abs(z) > MAXULONG
  */
-#if BASEB >= LONG_BITS
-#define zgtmaxulong(z)  ((z).len > 1)
-#else
-#define zgtmaxulong(z)  zgtmaxufull(z)
-#endif
+#  if BASEB >= LONG_BITS
+#    define zgtmaxulong(z) ((z).len > 1)
+#  else
+#    define zgtmaxulong(z) zgtmaxufull(z)
+#  endif
 
 /*
  * zgtmaxlong(z)        true if abs(z) > MAXLONG
  */
-#if BASEB >= LONG_BITS
-#define zgtmaxlong(z)   (((z).len > 1) || (((z).len == 1) && \
-                         (((SHALF)(z).v[0]) < 0)))
-#else
-#define zgtmaxlong(z)   zgtmaxfull(z)
-#endif
+#  if BASEB >= LONG_BITS
+#    define zgtmaxlong(z) (((z).len > 1) || (((z).len == 1) && (((SHALF)(z).v[0]) < 0)))
+#  else
+#    define zgtmaxlong(z) zgtmaxfull(z)
+#  endif
 
 /*
  * Some algorithms testing for values of a certain length.  Macros such as
@@ -543,40 +519,37 @@ E_FUNC void zredcpower(REDC *rp, ZVALUE z1, ZVALUE z2, ZVALUE *res);
  *      zge4096b(z)     true if abs(z) >= 2^4096
  *      zge8192b(z)     true if abs(z) >= 2^8192
  */
-#if BASEB == 32
+#  if BASEB == 32
 
-#define zge16b(z)       (!zistiny(z) || ((z).v[0] >= (HALF)0x10000))
-#define zge24b(z)       (!zistiny(z) || ((z).v[0] >= (HALF)0x1000000))
-#define zge31b(z)       (!zistiny(z) || (((SHALF)(z).v[0]) < 0))
-#define zge32b(z)       (!zistiny(z))
-#define zge64b(z)       ((z).len > 2)
-#define zge128b(z)      ((z).len > 4)
-#define zge256b(z)      ((z).len > 8)
-#define zge512b(z)      ((z).len > 16)
-#define zge1024b(z)     ((z).len > 32)
-#define zge2048b(z)     ((z).len > 64)
-#define zge4096b(z)     ((z).len > 128)
-#define zge8192b(z)     ((z).len > 256)
+#    define zge16b(z) (!zistiny(z) || ((z).v[0] >= (HALF)0x10000))
+#    define zge24b(z) (!zistiny(z) || ((z).v[0] >= (HALF)0x1000000))
+#    define zge31b(z) (!zistiny(z) || (((SHALF)(z).v[0]) < 0))
+#    define zge32b(z) (!zistiny(z))
+#    define zge64b(z) ((z).len > 2)
+#    define zge128b(z) ((z).len > 4)
+#    define zge256b(z) ((z).len > 8)
+#    define zge512b(z) ((z).len > 16)
+#    define zge1024b(z) ((z).len > 32)
+#    define zge2048b(z) ((z).len > 64)
+#    define zge4096b(z) ((z).len > 128)
+#    define zge8192b(z) ((z).len > 256)
 
-#else
+#  else
 
-#define zge16b(z)       (!zistiny(z))
-#define zge24b(z)       (((z).len > 2) || (((z).len == 2) && \
-                         ((z).v[1] >= (HALF)0x100)))
-#define zge31b(z)       (((z).len > 2) || (((z).len == 2) && \
-                         (((SHALF)(z).v[1]) < 0)))
-#define zge32b(z)       ((z).len > 2)
-#define zge64b(z)       ((z).len > 4)
-#define zge128b(z)      ((z).len > 8)
-#define zge256b(z)      ((z).len > 16)
-#define zge512b(z)      ((z).len > 32)
-#define zge1024b(z)     ((z).len > 64)
-#define zge2048b(z)     ((z).len > 128)
-#define zge4096b(z)     ((z).len > 256)
-#define zge8192b(z)     ((z).len > 512)
-
-#endif
+#    define zge16b(z) (!zistiny(z))
+#    define zge24b(z) (((z).len > 2) || (((z).len == 2) && ((z).v[1] >= (HALF)0x100)))
+#    define zge31b(z) (((z).len > 2) || (((z).len == 2) && (((SHALF)(z).v[1]) < 0)))
+#    define zge32b(z) ((z).len > 2)
+#    define zge64b(z) ((z).len > 4)
+#    define zge128b(z) ((z).len > 8)
+#    define zge256b(z) ((z).len > 16)
+#    define zge512b(z) ((z).len > 32)
+#    define zge1024b(z) ((z).len > 64)
+#    define zge2048b(z) ((z).len > 128)
+#    define zge4096b(z) ((z).len > 256)
+#    define zge8192b(z) ((z).len > 512)
 
+#  endif
 
 /*
  * ztofull - convert an absolute value of a ZVALUE to a FULL if possible
@@ -584,13 +557,10 @@ E_FUNC void zredcpower(REDC *rp, ZVALUE z1, ZVALUE z2, ZVALUE *res);
  * If the value is too large, only the low order bits that are able to
  * be converted into a FULL will be used.
  */
-#define ztofull(z)      (zistiny(z) ? ((FULL)((z).v[0])) :              \
-                                      ((FULL)((z).v[0]) +               \
-                                       ((FULL)((z).v[1]) << BASEB)))
+#  define ztofull(z) (zistiny(z) ? ((FULL)((z).v[0])) : ((FULL)((z).v[0]) + ((FULL)((z).v[1]) << BASEB)))
 
-#define z1tol(z)        ((long)((z).v[0]))
-#define z2tol(z)        ((long)(((z).v[0]) + \
-                                (((z).v[1] & MAXHALF) << BASEB)))
+#  define z1tol(z) ((long)((z).v[0]))
+#  define z2tol(z) ((long)(((z).v[0]) + (((z).v[1] & MAXHALF) << BASEB)))
 
 /*
  * ztoulong - convert an absolute value of a ZVALUE to an unsigned long
@@ -598,11 +568,11 @@ E_FUNC void zredcpower(REDC *rp, ZVALUE z1, ZVALUE z2, ZVALUE *res);
  * If the value is too large, only the low order bits that are able to
  * be converted into a long will be used.
  */
-#if BASEB >= LONG_BITS
-# define ztoulong(z)    ((unsigned long)z1tol(z))
-#else
-# define ztoulong(z)    ((unsigned long)ztofull(z))
-#endif
+#  if BASEB >= LONG_BITS
+#    define ztoulong(z) ((unsigned long)z1tol(z))
+#  else
+#    define ztoulong(z) ((unsigned long)ztofull(z))
+#  endif
 
 /*
  * ztolong - convert an absolute value of a ZVALUE to a long
@@ -610,39 +580,43 @@ E_FUNC void zredcpower(REDC *rp, ZVALUE z1, ZVALUE z2, ZVALUE *res);
  * If the value is too large, only the low order bits that are able to
  * be converted into a long will be used.
  */
-#define ztolong(z)      ((long)(ztoulong(z) & MAXLONG))
-
-#define zclearval(z)    memset((z).v, 0, (z).len * sizeof(HALF))
-#define zcopyval(z1,z2) memcpy((z2).v, (z1).v, (z1).len * sizeof(HALF))
-#define zquicktrim(z)   {if (((z).len > 1) && ((z).v[(z).len-1] == 0)) \
-                                (z).len--;}
-#define zfree(z)        {if ((z).len != 0 && (z).v != NULL) { \
-                            freeh((z).v); \
-                            (z).v = NULL; \
-                            (z).len = 0; \
-                            (z).sign = 0; } \
-                        }
+#  define ztolong(z) ((long)(ztoulong(z) & MAXLONG))
 
+#  define zclearval(z) memset((z).v, 0, (z).len * sizeof(HALF))
+#  define zcopyval(z1, z2) memcpy((z2).v, (z1).v, (z1).len * sizeof(HALF))
+#  define zquicktrim(z)                                   \
+      {                                                   \
+          if (((z).len > 1) && ((z).v[(z).len - 1] == 0)) \
+              (z).len--;                                  \
+      }
+#  define zfree(z)                             \
+      {                                        \
+          if ((z).len != 0 && (z).v != NULL) { \
+              freeh((z).v);                    \
+              (z).v = NULL;                    \
+              (z).len = 0;                     \
+              (z).sign = 0;                    \
+          }                                    \
+      }
 
 /*
  * Output modes for numeric displays.
  */
-#define MODE_DEFAULT    0
-#define MODE_FRAC       1
-#define MODE_INT        2
-#define MODE_REAL       3
-#define MODE_EXP        4
-#define MODE_HEX        5
-#define MODE_OCTAL      6
-#define MODE_BINARY     7
-#define MODE_REAL_AUTO  8
-#define MODE_ENG    9
-#define MODE_MAX        9
-#define MODE2_OFF       (MODE_MAX+1)
-
-#define MODE_INITIAL    MODE_REAL
-#define MODE2_INITIAL   MODE2_OFF
+#  define MODE_DEFAULT 0
+#  define MODE_FRAC 1
+#  define MODE_INT 2
+#  define MODE_REAL 3
+#  define MODE_EXP 4
+#  define MODE_HEX 5
+#  define MODE_OCTAL 6
+#  define MODE_BINARY 7
+#  define MODE_REAL_AUTO 8
+#  define MODE_ENG 9
+#  define MODE_MAX 9
+#  define MODE2_OFF (MODE_MAX + 1)
 
+#  define MODE_INITIAL MODE_REAL
+#  define MODE2_INITIAL MODE2_OFF
 
 /*
  * Output routines for either FILE handles or strings.
@@ -659,7 +633,6 @@ E_FUNC int math_setmode2(int mode);
 E_FUNC LEN math_setdigits(LEN digits);
 E_FUNC void math_fmt(char *, ...) __attribute__((format(printf, 1, 2)));
 
-
 /*
  * external swap functions
  */
@@ -670,7 +643,6 @@ E_FUNC HALF *swap_HALFs(HALF *dest, HALF *src, LEN len);
 E_FUNC ZVALUE *swap_b16_in_ZVALUE(ZVALUE *dest, ZVALUE *src, bool all);
 E_FUNC ZVALUE *swap_HALF_in_ZVALUE(ZVALUE *dest, ZVALUE *src, bool all);
 
-
 /*
  * constants used often by the arithmetic routines
  */
@@ -707,19 +679,18 @@ EXTERN ZVALUE _b64_;
 
 EXTERN HALF *half_tbl[]; /* preset HALF constants, NULL terminated list */
 
-EXTERN bool _math_abort_;       /* nonzero to abort calculations */
-EXTERN ZVALUE _tenpowers_[];    /* table of 10^2^n */
+EXTERN bool _math_abort_;    /* nonzero to abort calculations */
+EXTERN ZVALUE _tenpowers_[]; /* table of 10^2^n */
 
 /*
  * Bit fiddling functions and types
  */
-EXTERN HALF bitmask[];          /* bit rotation, norm 0 */
-EXTERN HALF lowhalf[];          /* bit masks from low end of HALF */
-EXTERN HALF rlowhalf[];         /* reversed bit masks from low end of HALF */
-EXTERN HALF highhalf[];         /* bit masks from high end of HALF */
-EXTERN HALF rhighhalf[];        /* reversed bit masks from high end of HALF */
-#define HAVE_REVERSED_MASKS     /* allows old code to know libcalc.a has them */
-
+EXTERN HALF bitmask[];        /* bit rotation, norm 0 */
+EXTERN HALF lowhalf[];        /* bit masks from low end of HALF */
+EXTERN HALF rlowhalf[];       /* reversed bit masks from low end of HALF */
+EXTERN HALF highhalf[];       /* bit masks from high end of HALF */
+EXTERN HALF rhighhalf[];      /* reversed bit masks from high end of HALF */
+#  define HAVE_REVERSED_MASKS /* allows old code to know libcalc.a has them */
 
 /*
  * BITSTR - string of bits within an array of HALFs
@@ -731,10 +702,9 @@ EXTERN HALF rhighhalf[];        /* reversed bit masks from high end of HALF */
  * significance may be found in previous bits and HALFs.
  */
 typedef struct {
-        HALF *loc;      /* half address of most significant bit */
-        int bit;        /* bit position within half of most significant bit */
-        int len;        /* length of string in bits */
+    HALF *loc; /* half address of most significant bit */
+    int bit;   /* bit position within half of most significant bit */
+    int len;   /* length of string in bits */
 } BITSTR;
 
-
 #endif /* !INCLUDE_ZMATH_H*/
